@@ -44,7 +44,7 @@ class Learner:
         # Input attributes
         self.log_dir = log_dir
         self.target_steps = target_steps
-        self.update_workers = workers.updater_workers()
+        self.update_workers = workers.update_workers()
 
         # Counters and metrics
         self.num_samples_collected = 0
